#ifndef jvmConst
#define jvmConst

/*
***************************************************
* File jvmConst: pushing constants onto the stack *
***************************************************
*/

#include "jvmStack.c"
#include "jvmConvert.c"
#include "jvmData.c"
  
void jb_bipush(void) {
  long val;
/* Meaning: Push a 1-byte signed integer. */
/*
  JEM format: bipush,byte1
  byte1 is a signed 1byte constant: if byte1 < 128 const = byte1 else const = byte1 | $FF00 
*/
  val = readJavaByte(getJvmPC()+1);
  val = b2i(val);
  push(val);
  incJvmPC(2);
}
  
  
void jb_sipush(void) {
  long val;
/* Meaning: Push a 2-byte signed integer. */
/*
  JEM format: sipush,byte1,byte2
  byte1 and byte2 form 16bits constant: const = (byte1<<8)|(byte2) 
*/
  val = readJavaIntBE(getJvmPC()+1);
  push(val);
  incJvmPC(3);
}  

void jb_ldc(void) {
  long index,val;
/* Meaning: Push item from constant pool. */
/*
  JEM format: ldc,byte1
  byte1 is index in String Indextable
*/
  index = readJavaByte(getJvmPC()+1);
  val = getLdc(index);
  push(val); 
  incJvmPC(2);
}  
   
void jb_ldc_w(void) {
  long index,val;
/*Meaning: Push 2-byte item from constant pool. */
/*
  JEM format: ldc_w,byte1,byte2
  byte1 is always 0. byte2 is index in String Indextable
*/
  index = readJavaByte(getJvmPC()+2);
  val = getLdc(index);
  push(val); 
  incJvmPC(3);
}

/*PUB jb_ldc_w2*/
/* Meaning: Push long or double from constant pool. */


void jb_aconst_null(void) {
/* Meaning: Push a null object reference. */
/*
  JEM format: aconst_null
*/
  push(0x0000);
  incJvmPC(1);
}  
  
void jb_iconst_m1(void) {
/* Meaning: Push the integer constant -1. */
/*
  JEM format: iconst_m1
*/
  push(0xFFFF);
  incJvmPC(1);
}
  
void jb_iconst_0(void) {
/* Meaning: Push the integer constant 0. */
/*
  JEM format: iconst_0
*/
  push(0x0000);
  incJvmPC(1);
}  

void jb_iconst_1(void) {
/* Meaning: Push the integer constant 1. */
/*
  JEM format: iconst_1
*/
  push(0x0001);
  incJvmPC(1);
}

void jb_iconst_2(void) {
/* Meaning: Push the integer constant 2. */
/*
  JEM format: iconst_2
*/
  push(0x0002);
  incJvmPC(1);
}

void jb_iconst_3(void) {
/* Meaning: Push the integer constant 3. */
/*
  JEM format: iconst_3
*/
  push(0x0003);
  incJvmPC(1);
}

void jb_iconst_4(void) {
/* Meaning: Push the integer constant 4. */
/*
  JEM format: iconst_4
*/
  push(0x0004);
  incJvmPC(1);
}

void jb_iconst_5(void) {
/* Meaning: Push the integer constant 5. */
/*
  JEM format: iconst_5
*/
  push(0x0005);
  incJvmPC(1);
}

/*PUB jb_lconst_0*/
/* Meaning: Push the long integer constant #0. */


/*PUB jb_lconst_1*/
/* Meaning: Push the long integer constant #1. */


/*PUB jb_fconst_0*/
/* Meaning: Push the single-precision floating-point number #0. */


/*PUB jb_fconst_1*/
/* Meaning: Push the single-precision floating-point number #1. */


/*PUB jb_fconst_2*/
/* Meaning: Push the single-precision floating-point number #2. */


/*PUB jb_dconst_0*/
/* Meaning: Push the double-precision floating-point number #0. */


/*PUB jb_dconst_1*/
/* Meaning: Push the double-precision floating-point number #1. */

#endif

